==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/lib_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_library'] = 							"add or edit a wiki page";
$lang['hdr_group_library'] = 					"add or edit a group wiki page for group 'GROUPTITLE'.";
$lang['section_library'] = 						"wiki page";


// FORMS
$lang['form_label_title'] = 					"Title";
$lang['form_label_synopsis'] = 					"Synopsis";
$lang['form_body'] = 							"Details";
$lang['form_submit_save_go'] = 					"SAVE AND GO";
$lang['form_submit_save'] = 					"SAVE";
$lang['form_submit_preview'] = 					"preview";
$lang['form_label_preview'] = 					"preview";
$lang['form_label_file'] = 						"thumbnail image";
$lang['form_label_genre'] = 					"Genre";
$lang['form_label_language'] = 					"Language";
$lang['form_label_comments'] = 					"Check to allow people to add comments to this event";
$lang['form_just_me'] = 						"just me";
$lang['form_rsp_group'] = 						"Check to submit this to the web site editor for inclusion on the group home page.";
$lang['form_rsp_node'] = 						"Check to submit this to the node editor for inclusion in Splash.";
$lang['form_rsp_group_auto'] = 					"Check to add this to the group home page.";
$lang['form_rsp_node_auto'] = 					"Check to add this to Splash.";



//ERRORS
$lang['err_library_item_edit'] = 				"Sorry, you can only edit your wiki pages.";


//BODY TEXT
$lang['txt_header_1'] = 						"1. Wiki page overview";
$lang['txt_overview_intro'] = 					"You can add a wiki page to this community. A wiki page is a document like a paper or page from of a manual or guide. Add a small synopsis which is a one line description of the wiki page to be used when displaying it in lists.";
$lang['txt_header_2'] = 						"2. Details";
$lang['txt_detail_intro'] = 					"Add your wiki page.";
$lang['txt_header_3'] = 						"3. Thumbnail image";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the wiki page on all lists. Choose one from the list below if desired.";
$lang['txt_header_4'] = 						"4. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this library item to be published to.";
$lang['txt_header_5'] = 						"5. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['txt_check_spelling'] = 					"check spelling";//
$lang['txt_publish_level'] =					"everyone";
$lang['txt_publish_node_help'] =				"Item will be submitted to Splash editor and can be viewed by any member of this community.";
$lang['txt_publish_public_help'] =				"Item will be submitted to web site editor and can be viewed by anyone.";
$lang['txt_publish_help'] =						"How wide do you want the audience of your wiki page to be? You can publish to just your friends, wider degrees of acquaintances or the Splash magazine page.";
$lang['txt_none'] = 							"none";
$lang['txt_default'] =							"default page";
$lang['txt_wiki_default'] = 					"LibraryFirstPage"; //must be WIKI formatted LikeThisExample

?>

==> aroundme_0_6_1.zip: aroundme_0_6_1/aroundme/language/1/barnraiser_01/lib_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'lib_view.lang.php');

//HEADER
$lang['hdr_library'] = 							"add or edit a wiki page";
$lang['hdr_library'] = 							"wiki page";


// FORMS
$lang['form_label_title'] = 					"Title";
$lang['form_label_synopsis'] = 					"Synopsis";
$lang['form_body'] = 							"Details";
$lang['form_label_preview'] = 					"preview";
$lang['form_label_file'] = 						"thumbnail image";
$lang['form_label_language'] = 					"Language";
$lang['form_label_comments'] = 					"Check to allow people to add comments to this wiki page";
$lang['form_just_me'] = 						"just me";
$lang['form_label_wiki_page'] = 				"Wiki page";
$lang['form_rsp_group'] = 						"Submit to group home page editor";
$lang['form_rsp_node'] = 						"Check to submit this to the node editor for inclusion in the 'stuff' section";
$lang['form_rsp_group_auto'] = 					"Add to group home page";
$lang['form_rsp_node_auto'] = 					"Add to 'stuff' section";


//BODY TEXT
$lang['txt_header_1'] = 						"1. Wiki page overview";
$lang['txt_overview_intro'] = 					"You can add a wiki page to this community. A wiki page is a document like a paper or page from of a manual or guide. Add a small synopsis which is a one line description of the wiki page to be used when displaying it in lists.";
$lang['txt_header_2'] = 						"2. Details";
$lang['txt_detail_intro'] = 					"Add your wiki page.";
$lang['txt_header_3'] = 						"3. Thumbnail image";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the wiki page on all lists. Choose one from the list below if desired.";
$lang['txt_header_4'] = 						"4. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this library item to be published to.";
$lang['txt_header_5'] = 						"5. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['sub_check_spelling'] = 					"check spelling";//
$lang['txt_publish_help'] =						"How wide do you want the audience of your wiki page to be? You can publish to just your friends, wider degrees of acquaintances or the Splash magazine page.";
$lang['txt_default'] =							"Default";
$lang['txt_none'] = 							"none";
$lang['txt_wiki_intro'] = 						"The Wiki page is the name of the page in Studly Caps format which LooksLikeThis. The default page is the first page in the Wiki.";

$lang['txt_publish_node_help'] =				"Submit to 'Stuff' editor";
$lang['txt_publish_auto_node_help'] = 			"Stuff";

$lang['txt_publish_public_help'] =				"Submit to public web site editor";
$lang['txt_publish_auto_public_help'] =			"public web site";

?>
